# Working with BiTIA CLI
The three commands that are the core of BiTIA's functionality are:
- run
- submit
- logs

<link type="text/css" href="../_static/./css/termynal.css" />


### Bitia run can be employed in the following ways:

#### 1. Running commands

<div id="termynal" data-termynal>
    <span data-ty="input">bitia run "samtools convert < foo.fa|http://y.com/foo.fa >"</span>
    <span data-ty="progress"></span>
</div>



The above code will: 
- Checks for the input file `foo.fa` in the current working directory
- Download the input file from the given link `http://example.com/foo.fa` and name it `foo.fa`
- Add the given command `samtools convert <foo.fa|http://example.com/foo.fa` into a pipeline file.
- Extract the current working directory with the pipeline as a zip file that contains a unique hash and send it to the server `public.bitia.link`
- The BiTIA runner in the server will execute the pipeline by: 
    - Installing the given command  `samtools`
    - Downloading the given input file from the link  `http://example.com/foo.fa` and name it `foo.fa`
    - Executing the command `samtools convert foo.fa` 
- Display the resulting output to the user console


#### 2. Running Pipelines

<div id="termynal1" data-termynal>
    <span data-ty="input">bitia run pipeline.sh</span>
    <span data-ty="progress"></span>
</div>




for `pipeline.sh`:
```bash
#!/usr/bin/env bash

fastqc *.gz

for file in *_1.fastq.gz
do
   trim_galore --cores 8 --gzip --fastqc --max_n 2 --output_dir Trimmed_Data/ --paired $file ${file%_1.fastq.gz}_2.fastq.gz
done

hisat2-build -p 8 ./Homo_sapiens/UCSC/hg38/Sequence/WholeGenomeFasta/genome.fa index
```

The above code will:
- Extract the current working directory with the `pipeline.sh` as a zip file containing a unique hash and send it to the public `server.bitia.link`
- The BiTIA runner in the server will execute the pipeline .
    - Installing the given commands `fastqc`, `trim_galore`,`hisat2`.
    - executing the commands given in the pipeline
- Displays the resulting output to the user console




<script type="text/javascript" src="https://raw.githack.com/tiangolo/fastapi/master/docs/en/docs/js/termynal.js" data-termynal-container="#termynal|#termynal1"></script>
           


                 